tlslite.integration.clienthelper

Package tlslite :: Package integration :: Module clienthelper |
[hide private]
[frames] | no frames]

# Module clienthelper

source code

A helper class for using TLS Lite with stdlib clients (httplib, xmlrpclib, imaplib, poplib).

Classes | [hide private]
| ClientHelper This is a helper class used to integrate TLS Lite with various TLS clients (e.g.

Variables | [hide private]
| __package__ = ``'``tlslite.integration``'``